# <img src="dep_cube.svg" width="32">Deposit GUI
GUI for [Deposit](https://github.com/demjanp/deposit): Graph database focused on scientific data collection.

Created on 29. 4. 2013

<details>
<summary>Table of Contents</summary>

2. [Installation](#installation)
3. [Contact](#contact)
4. [Acknowledgements](#acknowledgements)
5. [License](#license)

</details>


## Installation <a name="installation"></a>

For a Windows installer see:

https://github.com/demjanp/deposit_gui/releases/latest

To install the latest version of Deposit GUI as a Python module use:
```
pip install deposit_gui
```

To start the GUI execute:

[bin\start_gui.py](bin\start_gui.py)

## Contact: <a name="contact"></a>
Peter Demján (peter.demjan@gmail.com)

Institute of Archaeology of the Czech Academy of Sciences, Prague, v.v.i.

## Acknowledgements <a name="acknowledgements"></a>

Development of this software was supported by OP RDE, MEYS, under the project "Ultra-trace isotope research in social and environmental studies using accelerator mass spectrometry", Reg. No. CZ.02.1.01/0.0/0.0/16_019/0000728.

This software uses the following open source packages:
* [cryptography](https://github.com/pyca/cryptography)
* [Graphviz](https://www.graphviz.org/)
* [natsort](https://github.com/SethMMorton/natsort)
* [NetworKit](https://networkit.github.io/)
* [NetworkX](https://networkx.org/)
* [openpyxl](https://openpyxl.readthedocs.io/)
* [Pillow](https://python-pillow.org/)
* [Psycopg](https://psycopg.org/)
* [PyGraphviz](http://pygraphviz.github.io/)
* [PyShp](https://github.com/GeospatialPython/pyshp)
* [PySide2](https://www.pyside.org/)
* [Qt](https://www.qt.io)
* [Shapely](https://github.com/shapely/shapely)
* [svgelements](https://github.com/meerk40t/svgelements)
* [Unidecode](https://github.com/avian2/unidecode)
* [validators](https://github.com/kvesteri/validators)

## License <a name="license"></a>

This code is licensed under the [GNU GENERAL PUBLIC LICENSE](https://www.gnu.org/licenses/gpl-3.0.en.html) - see the [LICENSE](LICENSE) file for details
